@@ -7,9 +7,6 @@ from pollination.honeybee_radiance.sky import CreateSkyDome, CreateSkyMatrix
 from pollination.honeybee_radiance.grid import SplitGridFolder, MergeFolderData
 from pollination.honeybee_radiance.post_process import AnnualDaylightMetrics
 
-from pollination.honeybee_vtk.config import Config as VTKConfig
-from pollination.honeybee_vtk.translate import Translate as TranslateVTKJS
-
 # input/output alias
 from pollination.alias.inputs.model import hbjson_model_grid_input
 from pollination.alias.inputs.wea import wea_input_timestep_check
@@ -74,8 +71,10 @@ class AnnualDaylightEntryPoint(DAG):
     )
 
     model = Inputs.file(
-        description='A Honeybee model in HBJSON file format.',
-        extensions=['json', 'hbjson'],
+        description='A Honeybee Model JSON file (HBJSON) or a Model pkl (HBpkl) file. '
+        'This can also be a zipped version of a Radiance folder, in which case this '
+        'recipe will simply unzip the file and simulate it as-is.',
+        extensions=['json', 'hbjson', 'pkl', 'hbpkl', 'zip'],
         alias=hbjson_model_grid_input
     )
 
@@ -106,7 +105,8 @@ class AnnualDaylightEntryPoint(DAG):
     def generate_sunpath(self, north=north, wea=wea):
         """Create sunpath for sun-up-hours."""
         return [
-            {'from': CreateSunMatrix()._outputs.sunpath, 'to': 'resources/sunpath.mtx'},
+            {'from': CreateSunMatrix()._outputs.sunpath,
+             'to': 'resources/sunpath.mtx'},
             {
                 'from': CreateSunMatrix()._outputs.sun_modifiers,
                 'to': 'resources/suns.mod'
@@ -146,14 +146,14 @@ class AnnualDaylightEntryPoint(DAG):
         ]
 
     @task(
-        template=SplitGridFolder, needs=[create_rad_folder], 
+        template=SplitGridFolder, needs=[create_rad_folder],
         sub_paths={'input_folder': 'grid'}
     )
     def split_grid_folder(
         self, input_folder=create_rad_folder._outputs.model_folder,
         cpu_count=cpu_count, cpus_per_grid=3, min_sensor_count=min_sensor_count
     ):
-        """Split sensor grid folder based on the number of CPUs."""
+        """Split sensor grid folder based on the number of CPUs"""
         return [
             {
                 'from': SplitGridFolder()._outputs.output_folder,
@@ -170,7 +170,8 @@ class AnnualDaylightEntryPoint(DAG):
         ]
 
     @task(
-        template=CreateOctreeWithSky, needs=[generate_sunpath, create_rad_folder]
+        template=CreateOctreeWithSky, needs=[
+            generate_sunpath, create_rad_folder]
     )
     def create_octree_with_suns(
         self, model=create_rad_folder._outputs.model_folder,
@@ -194,7 +195,8 @@ class AnnualDaylightEntryPoint(DAG):
     @task(template=CreateSkyMatrix)
     def create_total_sky(self, north=north, wea=wea, sun_up_hours='sun-up-hours'):
         return [
-            {'from': CreateSkyMatrix()._outputs.sky_matrix, 'to': 'resources/sky.mtx'}
+            {'from': CreateSkyMatrix()._outputs.sky_matrix,
+             'to': 'resources/sky.mtx'}
         ]
 
     @task(template=CreateSkyMatrix)
@@ -224,8 +226,10 @@ class AnnualDaylightEntryPoint(DAG):
             create_total_sky, create_direct_sky, create_rad_folder, split_grid_folder
         ],
         loop=split_grid_folder._outputs.sensor_grids,
-        sub_folder='initial_results/{{item.full_id}}',  # create a subfolder for each grid
-        sub_paths={'sensor_grid': '{{item.full_id}}.pts'}  # sensor_grid sub_path
+        # create a subfolder for each grid
+        sub_folder='initial_results/{{item.full_id}}',
+        # sensor_grid sub_path
+        sub_paths={'sensor_grid': '{{item.full_id}}.pts'}
     )
     def annual_daylight_raytracing(
         self,
@@ -248,7 +252,9 @@ class AnnualDaylightEntryPoint(DAG):
         template=MergeFolderData,
         needs=[annual_daylight_raytracing]
     )
-    def restructure_results(self, input_folder='initial_results/final', extension='ill'):
+    def restructure_results(
+        self, input_folder='initial_results/final', extension='ill'
+    ):
         return [
             {
                 'from': MergeFolderData()._outputs.output_folder,
@@ -270,41 +276,10 @@ class AnnualDaylightEntryPoint(DAG):
             }
         ]
 
-    @task(
-        template=VTKConfig, needs=[calculate_annual_metrics],
-        sub_paths={'input_file': 'metrics_info.json'}
-    )
-    def convert_metrics_info(
-            self, input_file=calculate_annual_metrics._outputs.annual_metrics
-    ):
-        return [
-            {
-                'from': VTKConfig()._outputs.config,
-                'to': 'metrics/config.json'
-            }
-        ]
-
-    @task(template=TranslateVTKJS, needs=[convert_metrics_info])
-    def create_vtkjs(
-            self, hbjson_file=model, file_type='vtkjs', grid_options='points',
-            config_path=convert_metrics_info._outputs.config,
-            data='metrics'
-        ):
-        return [
-            {
-                'from': TranslateVTKJS()._outputs.output_file,
-                'to': 'visualization/annual_daylight.vtkjs'
-            }
-        ]
-
-    visualization = Outputs.file(
-        source='visualization/annual_daylight.vtkjs',
-        description='Results visualization in 3D in vtkjs format.'
-    )
-
     results = Outputs.folder(
         source='results', description='Folder with raw result files (.ill) that '
-        'contain illuminance matrices.', alias=annual_daylight_results
+        'contain illuminance matrices for each sensor at each timestep of the analysis.',
+        alias=annual_daylight_results
     )
 
     metrics = Outputs.folder(
